@@ -30,3 +30,12 @@ test_that("works with stratigraphic data", {
   ctc = function(x) rep(1, length(x))
   expect_identical(apply_taphonomy(x, pres_potential, ctc), x)
 })
+
+test_that("fossils object remains identical for perfect preservation",{
+  pres_potential = function(x) rep(1, length(x))
+  ctc = function(x) rep(1, length(x))
+  t = ape::rlineage(birth = 1, death = 0, Tmax = 1)
+  rate = 2
+  f = FossilSim::sim.fossils.poisson(rate = rate, tree = t)
+  expect_equal(apply_taphonomy(f, pres_potential, ctc), f)
+})
